*******************
Authors and Credits
*******************

MPDAF team at `CRAL <https://cral.univ-lyon1.fr/>`_
---------------------------------------------------

- `Roland Bacon <mailto:roland.bacon@univ-lyon1.fr>`_ scientific manager
- `Johan Richard <mailto:jrichard@univ-lyon1.fr>`_ scientific adviser
- `Laure Piqueras <mailto:laure.piqueras@univ-lyon1.fr>`_ lead developer
- `Simon Conseil <mailto:simon.conseil@univ-lyon1.fr>`_ lead developer
- `Martin Shepherd <mailto:martin.shepherd@univ-lyon1.fr>`_ developer
- `Yannick Roehlly <mailto:yannick.roehlly@univ-lyon1.fr>`_ developer

With contributions from

- `Aurélien Jarno <mailto:aurelien.jarno@univ-lyon1.fr>`_
- `David Carton <mailto:cartondj@gmail.com>`_
- `Floriane Leclercq <mailto:floriane.leclercq@univ-lyon1.fr>`_
- `Jarle Brinchman <mailto:jarle@strw.leidenuniv.nl>`_ (Leiden Observatory)
- `Markus Rexroth <mailto:markus.rexroth@epfl.ch>`_ (EPFL)
- `Ole Streicher <mailto:ole@aip.de>`_ (AIP)


Credits
-------

.. image:: _static/logo/muse-logo.png

.. image:: _static/logo/CRAL.jpeg

.. image:: _static/logo/logocnrs.jpeg

.. image:: _static/logo/ERC.png
